@@ -1,5 +1,5 @@
 """(fan) speed commands."""
-from typing import Any, Dict, Mapping, Union
+from typing import Any, Mapping, Union
 
 from ..events import FanSpeedEvent
 from ..message import HandlingResult
@@ -10,10 +10,11 @@ from .common import EventBus, SetCommand, _NoArgsCommand
 class FanSpeedLevel(DisplayNameIntEnum):
     """Enum class for all possible fan speed levels."""
 
+    # Values should be sort from low to high on their meanings
+    QUIET = 1000
     NORMAL = 0
     MAX = 1
     MAX_PLUS = 2, "max+"
-    QUIET = 1000
 
 
 class GetFanSpeed(_NoArgsCommand):
@@ -23,7 +24,7 @@ class GetFanSpeed(_NoArgsCommand):
 
     @classmethod
     def _handle_body_data_dict(
-        cls, event_bus: EventBus, data: Dict[str, Any]
+        cls, event_bus: EventBus, data: dict[str, Any]
     ) -> HandlingResult:
         """Handle message->body->data and notify the correct event subscribers.
 
