@@ -1,5 +1,5 @@
 """Water info commands."""
-from typing import Any, Dict, Mapping, Union
+from typing import Any, Mapping, Union
 
 from ..events import WaterAmount, WaterInfoEvent
 from ..message import HandlingResult
@@ -13,7 +13,7 @@ class GetWaterInfo(_NoArgsCommand):
 
     @classmethod
     def _handle_body_data_dict(
-        cls, event_bus: EventBus, data: Dict[str, Any]
+        cls, event_bus: EventBus, data: dict[str, Any]
     ) -> HandlingResult:
         """Handle message->body->data and notify the correct event subscribers.
 
