@@ -1,5 +1,5 @@
 """Stats commands."""
-from typing import Any, Dict
+from typing import Any
 
 from ..events import CleanJobStatus, ReportStatsEvent
 from ..events.event_bus import EventBus
@@ -13,7 +13,7 @@ class ReportStats(Message):
 
     @classmethod
     def _handle_body_data_dict(
-        cls, event_bus: EventBus, data: Dict[str, Any]
+        cls, event_bus: EventBus, data: dict[str, Any]
     ) -> HandlingResult:
         """Handle message->body->data and notify the correct event subscribers.
 
@@ -30,7 +30,7 @@ class ReportStats(Message):
             type=data.get("type"),
             cleaning_id=data["cid"],
             status=status,
-            rooms=[int(x) for x in data.get("content", "").split(",") if x],
+            content=[int(float(x)) for x in data.get("content", "").split(",") if x],
         )
         event_bus.notify(stats_event)
         return HandlingResult.success()
