@@ -1,14 +1,14 @@
 """MQTT module."""
 import json
 import ssl
-from typing import Dict, List, MutableMapping, Optional
+from typing import MutableMapping, Optional
 
 from cachetools import TTLCache
 from gmqtt import Client, Subscription
 from gmqtt.mqtt.constants import MQTTv311
 
 from .authentication import Authenticator
-from .commands import SET_COMMAND_NAMES, SetCommand
+from .commands import COMMANDS_WITH_MQTT_P2P_HANDLING, CommandWithMqttP2PHandling
 from .logging_filter import get_logger
 from .models import Configuration, Credentials, DeviceInfo
 from .vacuum_bot import VacuumBot
@@ -16,7 +16,7 @@ from .vacuum_bot import VacuumBot
 _LOGGER = get_logger(__name__)
 
 
-def _get_subscriptions(device_info: DeviceInfo) -> List[Subscription]:
+def _get_subscriptions(device_info: DeviceInfo) -> list[Subscription]:
     return [
         # iot/atr/[command]]/[did]]/[class]]/[resource]/j
         Subscription(
@@ -51,13 +51,13 @@ class MqttClient:
             self._hostname = "mq.ecouser.net"
 
         self._client: Optional[Client] = None
-        self._received_set_commands: MutableMapping[str, SetCommand] = TTLCache(
-            maxsize=60 * 60, ttl=60
-        )
+        self._received_p2p_commands: MutableMapping[
+            str, CommandWithMqttP2PHandling
+        ] = TTLCache(maxsize=60 * 60, ttl=60)
 
         # pylint: disable=unused-argument
         async def _on_message(
-            client: Client, topic: str, payload: bytes, qos: int, properties: Dict
+            client: Client, topic: str, payload: bytes, qos: int, properties: dict
         ) -> None:
             _LOGGER.debug("Got message: topic=%s; payload=%s;", topic, payload.decode())
             topic_split = topic.split("/")
@@ -81,7 +81,7 @@ class MqttClient:
     async def initialize(self) -> None:
         """Initialize MQTT."""
         if self._client:
-            self.disconnect()
+            await self.disconnect()
 
         credentials = await self._authenticator.authenticate()
         client_id = f"{credentials.user_id}@ecouser/{self._config.device_id}"
@@ -113,13 +113,13 @@ class MqttClient:
             for subscription in _get_subscriptions(device_info):
                 self._client.unsubscribe(subscription.topic)
 
-    def disconnect(self) -> None:
+    async def disconnect(self) -> None:
         """Disconnect from MQTT."""
         if self._client:
-            self._client.disconnect()
+            await self._client.disconnect()
         self._subscribers.clear()
 
-    async def _handle_atr(self, topic_split: List[str], payload: bytes) -> None:
+    async def _handle_atr(self, topic_split: list[str], payload: bytes) -> None:
         try:
             bot = self._subscribers.get(topic_split[3])
             if bot:
@@ -130,12 +130,12 @@ class MqttClient:
                 "An exception occurred during handling atr message", exc_info=True
             )
 
-    def _handle_p2p(self, topic_split: List[str], payload: bytes) -> None:
+    def _handle_p2p(self, topic_split: list[str], payload: bytes) -> None:
         try:
             command_name = topic_split[2]
-            command_type = SET_COMMAND_NAMES.get(command_name, None)
+            command_type = COMMANDS_WITH_MQTT_P2P_HANDLING.get(command_name, None)
             if command_type is None:
-                # command doesn't need special treatment or is not supported yet
+                # command does not support p2p handling (yet)
                 return
 
             is_request = topic_split[9] == "q"
@@ -153,12 +153,12 @@ class MqttClient:
                     )
                     return
 
-                self._received_set_commands[request_id] = command_type(**data)
+                self._received_p2p_commands[request_id] = command_type(**data)
             else:
-                command = self._received_set_commands.get(request_id, None)
+                command = self._received_p2p_commands.get(request_id, None)
                 if not command:
                     _LOGGER.debug(
-                        "Response to setCommand came in probably to late. requestId=%s, commandName=%s",
+                        "Response to command came in probably to late. requestId=%s, commandName=%s",
                         request_id,
                         command_name,
                     )
@@ -167,10 +167,7 @@ class MqttClient:
                 bot = self._subscribers.get(topic_split[3])
                 if bot:
                     data = json.loads(payload)
-                    if command.handle(bot.events, data) and isinstance(
-                        command.args, dict
-                    ):
-                        command.get_command.handle(bot.events, command.args)
+                    command.handle_mqtt_p2p(bot.events, data)
         except Exception:  # pylint: disable=broad-except
             _LOGGER.error(
                 "An exception occurred during handling p2p message", exc_info=True
